==> php82-nextcloud-28.0.6.tgz: share/nextcloud/apps/updatenotification/l10n/eu.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} eskuragarri dago. Lortu informazio gehiago eguneraketa nola egiteari buruz.",
    "Channel updated" : "Kanala eguneratuta",
    "Web updater is disabled" : "Web eguneratzailea desgaituta dago",
    "Update notifications" : "Eguneratu jakinarazpenak",
    "The update server could not be reached since %d days to check for new updates." : "Eguneratzeen zerbitzaria ezin izan da atzitu eguneratze berriak bilatzeko orain dela %d egunetik.",
    "Please check the Nextcloud and server log files for errors." : "Mesedez, egiaztatu Nextcloud eta zerbitzariaren erregistroko fitxategiak akatsak dauden ikusteko.",
    "Update to {serverAndVersion} is available." : "{serverAndVersion} eguneratzea eskuragarri dago.",
    "Update for {app} to version %s is available." : "{app}(r)entzako eguneraketa %s bertsiora eskuragarri dago.",
    "Update notification" : "Eguneratu jakinarazpena",
    "Update" : "Eguneratu",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Erabiltzen ari zaren bertsioak ez du mantenurik jasotzen dagoeneko. Eguneratu euskarria duen bertsio batera ahalik eta azkarren.",
    "Apps missing compatible version" : "Bertsio bateragarria falta duten aplikazioak",
    "View in store" : "Dendan ikusi",
    "Apps with compatible version" : "Bertsio bateragarria duten aplikazioak",
    "Open updater" : "Ireki eguneratzailea",
    "Download now" : "Deskargatu orain",
    "What's new?" : "Zer berri?",
    "View changelog" : "Ikusi aldaketen egunkaria",
    "The update check is not yet finished. Please refresh the page." : "Egunareketen egiaztapena ez da oraindik bukatu. Mesedez freskatu orria.",
    "Your version is up to date." : "Zure bertsioa eguneratuta dago.",
    "A non-default update server is in use to be checked for updates:" : "Lehenetsia ez den eguneratze zerbitzari bat dago martxan, eguneratze berriak bilatzeko:",
    "Update channel" : "Eguneratze-kanala",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Eguneratze-kanala aldatzeak aplikazioen kudeaketa orria eragiten du. Adib. beta kanalera aldatzean, beta eguneraketak eskainiko zaizkizu aplikazioen kudeaketa orrian.",
    "Current update channel:" : "Eguneratze-kanala:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Edozein unetan eguneratu dezakezu bertsio berri batera. Baina ezin da bertsio zahar egonkorrago batera itzuli.",
    "Notify members of the following groups about available updates:" : "Jakinarazi hurrengo taldeen kideei eskuragarri dauden eguneraketei buruz:",
    "No groups" : "Talderik ez",
    "Only notifications for app updates are available." : "Aplikazioen eguneratzeen jakinarazpenak soilik daude erabilgarri.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Aukeratutako eguneraketa kanala zerbitzariaren jakinarazpen dedikatuak zaharkitzen ditu.",
    "The selected update channel does not support updates of the server." : "Hautatutako eguneraketa kanalak ez ditu zerbitzariaren eguneraketak onartzen.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Bertsio berri bat dago eskuragarri: <strong>{newVersionString}</strong>",
    "Checking apps for compatible versions" : "Bertsio bateragarrientzat aplikaziorik dagoen egiaztatzen",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Ziurtatu config.php-k ez duela <samp> app store gaitua </samp>faltsu gisa ezartzen.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Ezin izan da appstore-arekin konektatu edo honek ez du eguneratzerik itzuli. Bilatu eskuz eguneratzeak edo ziurtatu zure zerbitzariak internet konexioa duela eta aplikazio biltegiarekin konektatu daitekeela.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong></strong>aplikazio guztiek Nextcloud bertsio honetarako bertsio bateragarria erabilgarri dute.",
    "Enterprise" : "Enpresa",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Enpresa erabilerarako. Ematen du beti azken adabaki maila, baina ez da berehala eguneratzen hurrengo bertsio nagusira. Eguneratze hori gertatzen da Nextcloud GmbH-k eskala handiko eta berebiziko garrantzia duten inplementazioetarako indartze eta probaketa osagarriak egin ondoren. Kanal hau bezeroentzako soilik dago erabilgarri eta Nextcloud Enterprise paketea ematen du.",
    "Stable" : "Egonkorra",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Bertsio egonkor berriena. Eguneroko erabilerarako prest dago eta beti eguneratuko da azken bertsio garrantzitsuenera.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Argitaratu aurreko bertsioa funtzionalitate berriak probatzeko soilik da, ez ekoizpen inguruneetarako.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["Aplikazio <strong>%n</strong>ek ez du Nextcloud bertsio honetarako bertsio bateragarririk erabilgarri.","<strong>%n</strong>palikaziok ez dute Nextcloud bertsio honetarako bertsio bateragarririk erabilgarri."],
    "Update to %1$s is available." : "%1$s-ra eguneratzea eskuragarri dago.",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Nextcloud eguneratzeko jakinarazpenak erakusten ditu eta SSO-a eskaintzen dio eguneratzaileari.",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Kontuan izan web eguneratzailea ez dela gomendatzen 100 erabiltzaile baino gehiagorekin! Mesedez, erabili komando-lerroko eguneratzailea horren ordez!",
    "Please use the command line updater to update." : "Mesedez, erabili komando-lerroko eguneratzailea eguneratzeko.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Behean eguneratze-kanala alda dezakezu eta horrek aplikazioen kudeaketa-orrian ere eragiten du. Adib. beta kanalera aldatu ondoren, beta aplikazioen eguneraketak aplikazioen kudeaketa orrian eskainiko zaizkizu.",
    "Update channel:" : "Eguneraketa kanala:",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Kontuan izan bertsio berri baten ondoren eguneratzea lehen bertsio txikia edo geroago bakarrik agertzen dela. Denboran zehar tartekatuta zabaltzen ditugu bertsio berriak gure erabiltzaileentzat eta batzuetan bertsio bat saltatu egiten dugu, arazoak aurkitzen direnean. Lortu informazio gehiago eguneratzeei eta kanalak askatzeari buruz {link} helbidean ",
    "Checked on {lastCheckedDate}" : "{lastCheckedDate}-n egiaztatuta"
},
"nplurals=2; plural=(n != 1);");

==> php82-nextcloud-30.0.5.tgz: share/nextcloud/apps/updatenotification/l10n/eu.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Channel updated" : "Kanala eguneratuta",
    "Web updater is disabled" : "Web eguneratzailea desgaituta dago",
    "App updated" : "Aplikazioa eguneratuta dago",
    "See what's new" : "Ikusi zer den berri",
    "{app} updated to version {version}" : "{app} eguneratuta dago {version} bertsioan",
    "Update notifications" : "Eguneratu jakinarazpenak",
    "The update server could not be reached since %d days to check for new updates." : "Eguneratzeen zerbitzaria ezin izan da atzitu eguneratze berriak bilatzeko orain dela %d egunetik.",
    "Please check the Nextcloud and server log files for errors." : "Mesedez, egiaztatu Nextcloud eta zerbitzariaren erregistroko fitxategiak akatsak dauden ikusteko.",
    "Update to {serverAndVersion} is available." : "{serverAndVersion} eguneratzea eskuragarri dago.",
    "Update for {app} to version %s is available." : "{app}(r)entzako eguneraketa %s bertsiora eskuragarri dago.",
    "Update notification" : "Eguneratu jakinarazpena",
    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "Nextcloud eguneratzeko jakinarazpenak eta aplikazioenak erakusten ditu, eta SSO-a eskaintzen dio eguneratzaileari.",
    "What's new in {app} {version}" : "Zer da berri {app} {version} bertsioan",
    "Give feedback" : "Eman feedback-a",
    "Get started" : "Hasi",
    "No changelog available" : "Ez dago aldaketen egunkaririk eskuragarri ",
    "Update" : "Eguneratu",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Erabiltzen ari zaren bertsioak ez du mantenurik jasotzen dagoeneko. Eguneratu euskarria duen bertsio batera ahalik eta azkarren.",
    "Apps missing compatible version" : "Bertsio bateragarria falta duten aplikazioak",
    "View in store" : "Dendan ikusi",
    "Apps with compatible version" : "Bertsio bateragarria duten aplikazioak",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "Kontuan izan eguneratzailea ez dela gomendatzen 100 erabiltzaile baino gehiago daudenean! Horren ordez erabili komando-lerroko eguneratzailea!",
    "Open updater" : "Ireki eguneratzailea",
    "Download now" : "Deskargatu orain",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Web eguneratzailea desgaituta dago. Eguneratzeko erabili komando-lerroko eguneratzailea edo zure instalazio motarentzat egokia den eguneratze mekanismoa (adib. Docker pull).",
    "What's new?" : "Zer berri?",
    "View changelog" : "Ikusi aldaketen egunkaria",
    "The update check is not yet finished. Please refresh the page." : "Egunareketen egiaztapena ez da oraindik bukatu. Mesedez freskatu orria.",
    "Your version is up to date." : "Zure bertsioa eguneratuta dago.",
    "A non-default update server is in use to be checked for updates:" : "Lehenetsia ez den eguneratze zerbitzari bat dago martxan, eguneratze berriak bilatzeko:",
    "Update channel" : "Eguneratze-kanala",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Eguneratze-kanala aldatzeak aplikazioen kudeaketa orria eragiten du. Adib. beta kanalera aldatzean, beta eguneraketak eskainiko zaizkizu aplikazioen kudeaketa orrian.",
    "Current update channel:" : "Eguneratze-kanala:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Edozein unetan eguneratu dezakezu bertsio berri batera. Baina ezin da bertsio zahar egonkorrago batera itzuli.",
    "Notify members of the following groups about available updates:" : "Jakinarazi hurrengo taldeen kideei eskuragarri dauden eguneraketei buruz:",
    "No groups" : "Talderik ez",
    "Only notifications for app updates are available." : "Aplikazioen eguneratzeen jakinarazpenak soilik daude erabilgarri.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Aukeratutako eguneraketa kanala zerbitzariaren jakinarazpen dedikatuak zaharkitzen ditu.",
    "The selected update channel does not support updates of the server." : "Hautatutako eguneraketa kanalak ez ditu zerbitzariaren eguneraketak onartzen.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Bertsio berri bat dago eskuragarri: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Kontuan izan bertsio berri baten ondoren eguneratzea lehen bertsio txikia edo geroago bakarrik agertzen dela. Denboran zehar tartekatuta zabaltzen ditugu bertsio berriak gure erabiltzaileentzat eta batzuetan bertsio bat saltatu egiten dugu, arazoak aurkitzen direnean. Lortu informazio gehiago eguneratzeei eta kanalak askatzeari buruz {link} helbidean ",
    "Checked on {lastCheckedDate} - Open changelog" : "{lastCheckedDate} datan egiaztatuta - Ireki aldaketen egunkaria",
    "Checking apps for compatible versions" : "Bertsio bateragarrientzat aplikaziorik dagoen egiaztatzen",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Ziurtatu config.php-k ez duela <samp> app store gaitua </samp>faltsu gisa ezartzen.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Ezin izan da appstore-arekin konektatu edo honek ez du eguneratzerik itzuli. Bilatu eskuz eguneratzeak edo ziurtatu zure zerbitzariak internet konexioa duela eta aplikazio biltegiarekin konektatu daitekeela.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong></strong>aplikazio guztiek Nextcloud bertsio honetarako bertsio bateragarria erabilgarri dute.",
    "Enterprise" : "Enpresa",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Enpresa erabilerarako. Ematen du beti azken adabaki maila, baina ez da berehala eguneratzen hurrengo bertsio nagusira. Eguneratze hori gertatzen da Nextcloud GmbH-k eskala handiko eta berebiziko garrantzia duten inplementazioetarako indartze eta probaketa osagarriak egin ondoren. Kanal hau bezeroentzako soilik dago erabilgarri eta Nextcloud Enterprise paketea ematen du.",
    "Stable" : "Egonkorra",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Bertsio egonkor berriena. Eguneroko erabilerarako prest dago eta beti eguneratuko da azken bertsio garrantzitsuenera.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Argitaratu aurreko bertsioa funtzionalitate berriak probatzeko soilik da, ez ekoizpen inguruneetarako.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["Aplikazio <strong>%n</strong>ek ez du Nextcloud bertsio honetarako bertsio bateragarririk erabilgarri.","<strong>%n</strong>palikaziok ez dute Nextcloud bertsio honetarako bertsio bateragarririk erabilgarri."],
    "Changelog for app {app}" : "{app} aplikazioaren aldaketen egunkaria",
    "What's new in {app} version {version}" : "Zer da berri {app} {version} bertsioan",
    "{version} is available. Get more information on how to update." : "{version} eskuragarri dago. Lortu informazio gehiago eguneraketa nola egiteari buruz.",
    "Update to %1$s is available." : "%1$s-ra eguneratzea eskuragarri dago.",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Nextcloud eguneratzeko jakinarazpenak erakusten ditu eta SSO-a eskaintzen dio eguneratzaileari.",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Kontuan izan web eguneratzailea ez dela gomendatzen 100 erabiltzaile baino gehiagorekin! Mesedez, erabili komando-lerroko eguneratzailea horren ordez!",
    "Please use the command line updater to update." : "Mesedez, erabili komando-lerroko eguneratzailea eguneratzeko.",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Kontuan izan bertsio berri baten ondoren eguneratzea lehen bertsio txikia edo geroago bakarrik agertzen dela. Denboran zehar tartekatuta zabaltzen ditugu bertsio berriak gure erabiltzaileentzat eta batzuetan bertsio bat saltatu egiten dugu, arazoak aurkitzen direnean. Lortu informazio gehiago eguneratzeei eta kanalak askatzeari buruz {link} helbidean "
},
"nplurals=2; plural=(n != 1);");
